@@ -1,4 +1,4 @@
-package B::OPCheck; # git description: 0.29-6-g1b4433f
+package B::OPCheck; # git description: v0.30-5-g322358c
 # ABSTRACT: PL_check hacks using Perl callbacks
 
 use 5.008;
@@ -12,7 +12,7 @@ use Scalar::Util;
 use Scope::Guard;
 use B::Utils 0.08 ();
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 XSLoader::load 'B::OPCheck', $VERSION;
 
@@ -57,7 +57,7 @@ B::OPCheck - PL_check hacks using Perl callbacks
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -134,17 +134,17 @@ Chia-liang Kao <clkao@clkao.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Florian Ragwitz Karen Etheridge Alexandr Ciornii
+=for stopwords Karen Etheridge Florian Ragwitz Alexandr Ciornii
 
 =over 4
 
 =item *
 
-Florian Ragwitz <rafl@debian.org>
+Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
+Florian Ragwitz <rafl@debian.org>
 
 =item *
 
